%% Core Vector Machine 
%  -- classification method --
%
% Input:
%       Model        - struct, obtained from core_pvm
%       fKernelPtr   - pointer to a valid N x (N+M) kernel matrix providing access to
%                      the training data kernel in N x N followed (remaining
%                      columns) with the kernel data for new M test data N x M
%       vTestIndices - M x 1 vector e.g. [1:M] - selecting the test data which are to classify 
%
% Output:
%       PredictedLabel - 1 if point is in the circle 0 otherwise
%       DistCenter     - distance to the center
%
% (C) 2014 by Frank-Michael Schleif
% schleif@informatik.uni-leipzig.de

function [PredictedLabel,DistCenter] = core_pvm_classify(oModel,fKernelPtr, vTestIndices,varargin)
    fClassifier        = @(Range)sum(bsxfun(@times,fKernelPtr(oModel.CoreVectors,Range), oModel.Alphas  .* oModel.L(oModel.CoreVectors)))+oModel.bias;
    DistCenter         = fClassifier(vTestIndices);
    PredictedLabel     = DistCenter<0;

