%% Core Vector Machine (with probabilistic speed up)
%  - multi class wrapper - 
%
% Input:
%       fKernel   - pointer to a valid kernel function f(i,j)
%       L         - N x 1 - numeric, label vector 0/1
%
% Output:
%       vModels        - #unique(L) x 1 vector of CVM models
%       vUnique        - Mapping of the predicted label (e.g. in case of gaps) to the original labels
%       PredictedLabel - predicted labels 
% (C) 2012 by Frank-Michael Schleif
% schleif@informatik.uni-leipzig.de

function [vModels,vUnique,PredictedLabel] = core_pvm_mc(fKernelPtr,vLabel,varargin)
    C            = 10;
    if(numel(varargin)>1)
        C= varargin{2};
    end
            
    N       = numel(vLabel);    
    vUnique = unique(vLabel);
    L       = numel(vUnique);
    DistCenter = zeros(L,N);
    Epsilon    = 0.001; 
    PredictedLabel = [];
    diags            = [];
    if(~isempty(varargin))
        diags = varargin{1};
    end
        
	for(i=1:L)
        vCurrentLabel = ones(numel(vLabel),1);
        vCurrentLabel(vLabel == vUnique(i)) = 0;

        Y            = (vCurrentLabel-0.5)*2;
        oModel       = core_pvm(fKernelPtr,Y,Epsilon,diags,C);
        vModels(i)   = oModel;       
    end
    if(nargout>2)
        for(i=1:L)
                [~,DistCenter(i,:)] = core_pvm_classify(vModels(i),fKernelPtr, [1:N]);
        end
        PredictedLabel = argmin(DistCenter); 
    end
